@@ -52,6 +52,7 @@
 #include <sensor_msgs/JointState.h>
 #include <nav_msgs/Odometry.h>
 #include <std_msgs/Float64.h>
+#include <std_msgs/String.h>
 
 #include "rm_common/ros_utilities.h"
 #include "rm_common/decision/heat_limit.h"
@@ -234,10 +235,9 @@ public:
   {
     power_limit_->setRefereeStatus(status);
   }
-
-  void sendCommand(const ros::Time& time) override
+  void sendChassisCommand(const ros::Time& time, bool is_gyro)
   {
-    power_limit_->setLimitPower(msg_);
+    power_limit_->setLimitPower(msg_, is_gyro);
     msg_.accel.linear.x = accel_x_.output(msg_.power_limit);
     msg_.accel.linear.y = accel_y_.output(msg_.power_limit);
     msg_.accel.angular.z = accel_z_.output(msg_.power_limit);
@@ -294,7 +294,6 @@ public:
   }
 
 private:
-  ros::Time last_track_;
   double max_yaw_rate_{}, max_pitch_vel_{}, track_timeout_{}, eject_sensitivity_ = 1.;
   bool eject_flag_{};
 };
@@ -318,10 +317,6 @@ public:
       target_acceleration_tolerance_ = 0.;
       ROS_INFO("target_acceleration_tolerance no defined(namespace: %s), set to zero.", nh.getNamespace().c_str());
     }
-    double moving_average_num;
-    nh.param("accleration_moving_average_num", moving_average_num, 1.);
-    acceleration_filter_ = new MovingAverageFilter<double>(moving_average_num);
-    track_target_acceleration_ = 0.;
   }
   ~ShooterCommandSender()
   {
@@ -348,24 +343,10 @@ public:
   {
     track_data_ = data;
   }
-
-  void computeTargetAcceleration()
-  {
-    auto target_vel = track_data_.target_vel;
-    double current_target_vel = sqrt(pow(target_vel.x, 2) + pow(target_vel.y, 2) + pow(target_vel.z, 2));
-    double current_time = track_data_.header.stamp.toSec();
-    if (current_time == last_target_time_)
-      return;
-    track_target_acceleration_ = (current_target_vel - last_target_vel_) / (current_time - last_target_time_);
-    last_target_vel_ = current_target_vel;
-    last_target_time_ = current_time;
-    acceleration_filter_->input(track_target_acceleration_);
-    track_target_acceleration_ = acceleration_filter_->output();
-  }
   void checkError(const ros::Time& time)
   {
     if ((gimbal_des_error_.error > gimbal_error_tolerance_ && time - gimbal_des_error_.stamp < ros::Duration(0.1)) ||
-        (track_target_acceleration_ > target_acceleration_tolerance_))
+        (track_data_.accel > target_acceleration_tolerance_))
       if (msg_.mode == rm_msgs::ShootCmd::PUSH)
         setMode(rm_msgs::ShootCmd::READY);
   }
@@ -407,12 +388,8 @@ private:
   double speed_10_, speed_15_, speed_16_, speed_18_, speed_30_;
   double gimbal_error_tolerance_{};
   double target_acceleration_tolerance_{};
-  double track_target_acceleration_;
-  double last_target_vel_ = 0.;
-  double last_target_time_ = 0.;
   rm_msgs::TrackData track_data_;
   rm_msgs::GimbalDesError gimbal_des_error_;
-  MovingAverageFilter<double>* acceleration_filter_;
 };
 
 class Vel3DCommandSender : public HeaderStampCommandSenderBase<geometry_msgs::TwistStamped>
@@ -606,4 +583,26 @@ private:
   int index_{};
   const sensor_msgs::JointState& joint_state_;
 };
+
+class CameraSwitchCommandSender : public CommandSenderBase<std_msgs::String>
+{
+public:
+  explicit CameraSwitchCommandSender(ros::NodeHandle& nh) : CommandSenderBase<std_msgs::String>(nh)
+  {
+    ROS_ASSERT(nh.getParam("camera1_name", camera1_name_) && nh.getParam("camera2_name", camera2_name_));
+    msg_.data = camera1_name_;
+  }
+  void switchCamera()
+  {
+    msg_.data = msg_.data == camera1_name_ ? camera2_name_ : camera1_name_;
+  }
+  void sendCommand(const ros::Time& time) override
+  {
+    CommandSenderBase<std_msgs::String>::sendCommand(time);
+  }
+  void setZero() override{};
+
+private:
+  std::string camera1_name_{}, camera2_name_{};
+};
 }  // namespace rm_common
